@@ -9,7 +9,7 @@
 package WebService::HashiCorp::Vault;
 
 use Moo;
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 extends 'WebService::HashiCorp::Vault::Base';
 use namespace::clean;
@@ -50,11 +50,13 @@ use WebService::HashiCorp::Vault::Sys;
 sub secret {
     my $self = shift;
     my %args = @_;
-    $args{approle}  = $self->approle();
-    $args{token}    = $self->token();
-    $args{version}  = $self->version();
-    $args{base_url} = $self->base_url();
-    $args{ua}       = $self->ua();
+    $args{approle}    = $self->approle();
+    $args{base_url}   = $self->base_url();
+    $args{log_method} = $self->log_method();
+    $args{logger}     = $self->logger();
+    $args{token}      = $self->token();
+    $args{ua}         = $self->ua();
+    $args{version}    = $self->version();
 
     $args{backend} ||= 'generic';
     die sprintf( "Unknown backend type: %s\n", $args{backend} )
@@ -93,7 +95,7 @@ WebService::HashiCorp::Vault - Perl API for HashiCorp's Vault
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -154,7 +156,7 @@ Here are the currently supported options:
 
 =item L<Generic|WebService::HashiCorp::Vault::Secret::Generic>
 
-=item L<Generic|WebService::HashiCorp::Vault::Secret::Kvv2>
+=item L<Kvv|WebService::HashiCorp::Vault::Secret::Kvv2>
 
 =item L<MongoDB|WebService::HashiCorp::Vault::Secret::MongoDB>
 
@@ -211,7 +213,7 @@ Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Dean Hamstad.
+This software is Copyright (c) 2025 by Dean Hamstad.
 
 This is free software, licensed under:
 
